==> bitcoin-0.16.0.tar.gz: bitcoin-0.16.0/src/qt/locale/bitcoin_zh-Hans.ts <==
<TS language="zh-Hans" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>右击编辑地址或标签</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>创建一个新的地址</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>复制选定的地址到系统剪切板</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>从列表删除选定的地址</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>导出当前数据到文件</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>选择发送比特币地址</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>选择接收比特币地址</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>选择</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>发送地址</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>接收地址</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>这是你的比特币发币地址。发送前请确认发送数量和接收地址</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>这是你的比特币接收地址。建议每次交易都使用新地址</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>复制标签</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>导出地址列表</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>导出失败</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Encrypt wallet</source>
        <translation>加密钱包</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Exporting Failed</source>
        <translation>导出失败</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>导出当前数据到文件</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>

==> bitcoin-0.19.1.tar.gz: bitcoin-0.19.1/src/qt/locale/bitcoin_zh-Hans.ts <==
<TS language="zh-Hans" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>右击编辑地址或标签</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>创建一个新的地址</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>复制选定的地址到系统剪切板</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>从列表删除选定的地址</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>导出当前数据到文件</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>选择发送比特币地址</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>选择接收比特币地址</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>选择</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>发送地址</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>接收地址</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>这是你的比特币发币地址。发送前请确认发送数量和接收地址</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>复制地址</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>复制标签</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>导出地址列表</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>逗号分隔文件(*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>导出失败</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>保存地址列表至%1时发生错误，请重试。</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Encrypt wallet</source>
        <translation>加密钱包</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(无标签)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>逗号分隔文件(*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>导出失败</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>导出当前数据到文件</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
